zilore
    * ``auth_key`` Specify the zilore api key to use


.. note::
   
   Zilore API requires an API key that can be found in your Zilore profile, at the API tab.
   The API access is available only for paid plans.
   

